==> haskell-stmonadtrans-0.4.4-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.4
id: STMonadTrans-0.4.4-4a1MnFXjOE9659mRdznJrQ
key: STMonadTrans-0.4.4-4a1MnFXjOE9659mRdznJrQ
license: BSD-3-Clause
maintainer: josef.svenningsson@gmail.com
author: Josef Svenningsson
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
abi: 81622377a3b3a20b9c612a4ac20a4004
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/STMonadTrans-0.4.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/STMonadTrans-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/STMonadTrans-0.4.4
hs-libraries: HSSTMonadTrans-0.4.4-4a1MnFXjOE9659mRdznJrQ
depends:
    array-0.5.3.0 base-4.12.0.0 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stmonadtrans-0.4.4-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stmonadtrans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: STMonadTrans
version: 0.4.4
id: STMonadTrans-0.4.4-3XDrdFUoKD4J6hceAFpvG5
key: STMonadTrans-0.4.4-3XDrdFUoKD4J6hceAFpvG5
license: BSD-3-Clause
maintainer: josef.svenningsson@gmail.com
author: Josef Svenningsson
synopsis: A monad transformer version of the ST monad
description:
    A monad transformer version of the ST monad
    Warning! This monad transformer should not be used with monads that
    can contain multiple answers, like the list monad. The reason is that
    the state token will be duplicated across the different answers and
    this causes Bad Things to happen (such as loss of referential
    transparency). Safe monads include the monads State, Reader, Writer,
    Maybe and combinations of their corresponding monad transformers.
category: Monads
abi: 5f3d922c03c89e88f1586ebc706d4edd
exposed: True
exposed-modules:
    Control.Monad.ST.Trans Control.Monad.ST.Trans.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/STMonadTrans-0.4.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/STMonadTrans-0.4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/STMonadTrans-0.4.4
hs-libraries: HSSTMonadTrans-0.4.4-3XDrdFUoKD4J6hceAFpvG5
depends:
    array-0.5.3.0 base-4.12.0.0 mtl-2.2.2
haddock-interfaces: /usr/share/doc/haskell-stmonadtrans/html/STMonadTrans.haddock
haddock-html: /usr/share/doc/haskell-stmonadtrans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
